@@ -722,7 +722,11 @@ dzl_tree_node_finalize (GObject *object)
   DzlTreeNode *self = DZL_TREE_NODE (object);
 
   g_clear_object (&self->item);
-  dzl_clear_pointer (&self->text, g_free);
+  g_clear_object (&self->gicon);
+  g_clear_pointer (&self->text, g_free);
+
+  g_list_free_full (self->emblems, g_free);
+  self->emblems = NULL;
 
   dzl_clear_weak_pointer (&self->tree);
   dzl_clear_weak_pointer (&self->parent);
@@ -1082,7 +1086,7 @@ dzl_tree_node_show_popover (DzlTreeNode *self,
 
       path = dzl_tree_node_get_path (self);
       gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (tree), path, NULL, FALSE, 0, 0);
-      dzl_clear_pointer (&path, gtk_tree_path_free);
+      g_clear_pointer (&path, gtk_tree_path_free);
 
       /*
        * FIXME: Time period comes from gtk animation duration.
